@@ -14,7 +14,11 @@ struct git_hash_ctx {
     mbedtls_sha1_context c;
 };
 
-#define git_hash_global_init() 0
 #define git_hash_ctx_init(ctx) git_hash_init(ctx)
 
+GIT_INLINE(int) git_hash_global_init(void)
+{
+	return 0;
+}
+
 #endif /* INCLUDE_hash_mbedtld_h__ */
