@@ -13,8 +13,11 @@
 
 extern int git_openssl_stream_global_init(void);
 
-extern int git_openssl_stream_new(git_stream **out, const char *host, const char *port);
-
+#ifdef GIT_OPENSSL
 extern int git_openssl__set_cert_location(const char *file, const char *path);
 
+extern int git_openssl_stream_new(git_stream **out, const char *host, const char *port);
+extern int git_openssl_stream_wrap(git_stream **out, git_stream *in, const char *host);
+#endif
+
 #endif
