@@ -307,44 +307,44 @@ static int on_header_ready(http_subtransport *t)
 
 	if (!strcasecmp("Content-Type", git_buf_cstr(name))) {
 		if (t->content_type) {
-			giterr_set(GITERR_NET, "multiple Content-Type headers");
+			git_error_set(GIT_ERROR_NET, "multiple Content-Type headers");
 			return -1;
 		}
 
 		t->content_type = git__strdup(git_buf_cstr(value));
-		GITERR_CHECK_ALLOC(t->content_type);
+		GIT_ERROR_CHECK_ALLOC(t->content_type);
 	}
 	else if (!strcasecmp("Content-Length", git_buf_cstr(name))) {
 		if (t->content_length) {
-			giterr_set(GITERR_NET, "multiple Content-Length headers");
+			git_error_set(GIT_ERROR_NET, "multiple Content-Length headers");
 			return -1;
 		}
 
 		t->content_length = git__strdup(git_buf_cstr(value));
-		GITERR_CHECK_ALLOC(t->content_length);
+		GIT_ERROR_CHECK_ALLOC(t->content_length);
 	}
 	else if (!strcasecmp("Proxy-Authenticate", git_buf_cstr(name))) {
 		char *dup = git__strdup(git_buf_cstr(value));
-		GITERR_CHECK_ALLOC(dup);
+		GIT_ERROR_CHECK_ALLOC(dup);
 
 		if (git_vector_insert(&t->proxy.auth_challenges, dup) < 0)
 			return -1;
 	}
 	else if (!strcasecmp("WWW-Authenticate", git_buf_cstr(name))) {
 		char *dup = git__strdup(git_buf_cstr(value));
-		GITERR_CHECK_ALLOC(dup);
+		GIT_ERROR_CHECK_ALLOC(dup);
 
 		if (git_vector_insert(&t->server.auth_challenges, dup) < 0)
 			return -1;
 	}
 	else if (!strcasecmp("Location", git_buf_cstr(name))) {
 		if (t->location) {
-			giterr_set(GITERR_NET, "multiple Location headers");
+			git_error_set(GIT_ERROR_NET, "multiple Location headers");
 			return -1;
 		}
 
 		t->location = git__strdup(git_buf_cstr(value));
-		GITERR_CHECK_ALLOC(t->location);
+		GIT_ERROR_CHECK_ALLOC(t->location);
 	}
 
 	return 0;
@@ -411,7 +411,7 @@ static int on_auth_required(
 	int ret;
 
 	if (!allowed_types) {
-		giterr_set(GITERR_NET, "%s requested authentication but did not negotiate mechanisms", type);
+		git_error_set(GIT_ERROR_NET, "%s requested authentication but did not negotiate mechanisms", type);
 		t->parse_error = PARSE_ERROR_GENERIC;
 		return t->parse_error;
 	}
@@ -430,7 +430,7 @@ static int on_auth_required(
 			assert(*creds);
 
 			if (!((*creds)->credtype & allowed_types)) {
-				giterr_set(GITERR_NET, "%s credential provider returned an invalid cred type", type);
+				git_error_set(GIT_ERROR_NET, "%s credential provider returned an invalid cred type", type);
 				t->parse_error = PARSE_ERROR_GENERIC;
 				return t->parse_error;
 			}
@@ -441,7 +441,7 @@ static int on_auth_required(
 		}
 	}
 
-	giterr_set(GITERR_NET, "%s authentication required but no callback set",
+	git_error_set(GIT_ERROR_NET, "%s authentication required but no callback set",
 		type);
 	t->parse_error = PARSE_ERROR_GENERIC;
 	return t->parse_error;
@@ -457,7 +457,7 @@ static int on_headers_complete(http_parser *parser)
 
 	/* Enforce a reasonable cap on the number of replays */
 	if (t->replay_count++ >= GIT_HTTP_REPLAY_MAX) {
-		giterr_set(GITERR_NET, "too many redirects or authentication replays");
+		git_error_set(GIT_ERROR_NET, "too many redirects or authentication replays");
 		return t->parse_error = PARSE_ERROR_GENERIC;
 	}
 
@@ -525,7 +525,7 @@ static int on_headers_complete(http_parser *parser)
 
 	/* Check for a 200 HTTP status code. */
 	if (parser->status_code != 200) {
-		giterr_set(GITERR_NET,
+		git_error_set(GIT_ERROR_NET,
 			"unexpected HTTP status code: %d",
 			parser->status_code);
 		return t->parse_error = PARSE_ERROR_GENERIC;
@@ -533,7 +533,7 @@ static int on_headers_complete(http_parser *parser)
 
 	/* The response must contain a Content-Type header. */
 	if (!t->content_type) {
-		giterr_set(GITERR_NET, "no Content-Type header in response");
+		git_error_set(GIT_ERROR_NET, "no Content-Type header in response");
 		return t->parse_error = PARSE_ERROR_GENERIC;
 	}
 
@@ -552,7 +552,7 @@ static int on_headers_complete(http_parser *parser)
 
 	if (strcmp(t->content_type, git_buf_cstr(&buf))) {
 		git_buf_dispose(&buf);
-		giterr_set(GITERR_NET,
+		git_error_set(GIT_ERROR_NET,
 			"invalid Content-Type: %s",
 			t->content_type);
 		return t->parse_error = PARSE_ERROR_GENERIC;
@@ -588,7 +588,7 @@ static int on_body_fill_buffer(http_parser *parser, const char *str, size_t len)
 	/* If there's no buffer set, we're explicitly ignoring the body. */
 	if (ctx->buffer) {
 		if (ctx->buf_size < len) {
-			giterr_set(GITERR_NET, "can't fit data in the buffer");
+			git_error_set(GIT_ERROR_NET, "can't fit data in the buffer");
 			return t->parse_error = PARSE_ERROR_GENERIC;
 		}
 
@@ -643,7 +643,7 @@ static int write_chunk(git_stream *io, const char *buffer, size_t len)
 	if (git_buf_oom(&buf))
 		return -1;
 
-	if (git_stream_write(io, buf.ptr, buf.size, 0) < 0) {
+	if (git_stream__write_full(io, buf.ptr, buf.size, 0) < 0) {
 		git_buf_dispose(&buf);
 		return -1;
 	}
@@ -651,11 +651,11 @@ static int write_chunk(git_stream *io, const char *buffer, size_t len)
 	git_buf_dispose(&buf);
 
 	/* Chunk body */
-	if (len > 0 && git_stream_write(io, buffer, len, 0) < 0)
+	if (len > 0 && git_stream__write_full(io, buffer, len, 0) < 0)
 		return -1;
 
 	/* Chunk footer */
-	if (git_stream_write(io, "\r\n", 2, 0) < 0)
+	if (git_stream__write_full(io, "\r\n", 2, 0) < 0)
 		return -1;
 
 	return 0;
@@ -679,6 +679,9 @@ static int load_proxy_config(http_subtransport *t)
 		    !!t->server.url.use_ssl, &t->proxy_url)) < 0)
 			return error;
 
+		if (!t->proxy_url)
+			return 0;
+
 		t->proxy_opts.type = GIT_PROXY_SPECIFIED;
 		t->proxy_opts.url = t->proxy_url;
 		t->proxy_opts.credentials = t->owner->proxy.credentials;
@@ -699,7 +702,7 @@ static int load_proxy_config(http_subtransport *t)
 		return error;
 
 	if (t->proxy.url.use_ssl) {
-		giterr_set(GITERR_NET, "SSL connections to proxy are not supported");
+		git_error_set(GIT_ERROR_NET, "SSL connections to proxy are not supported");
 		return -1;
 	}
 
@@ -720,18 +723,18 @@ static int check_certificate(
 	if ((error = git_stream_certificate(&cert, stream)) < 0)
 		return error;
 
-	giterr_state_capture(&last_error, GIT_ECERTIFICATE);
+	git_error_state_capture(&last_error, GIT_ECERTIFICATE);
 
 	error = cert_cb(cert, is_valid, url->host, cert_cb_payload);
 
 	if (error == GIT_PASSTHROUGH && !is_valid)
-		return giterr_state_restore(&last_error);
+		return git_error_state_restore(&last_error);
 	else if (error == GIT_PASSTHROUGH)
 		error = 0;
-	else if (error && !giterr_last())
-		giterr_set(GITERR_NET, "user rejected certificate for %s", url->host);
+	else if (error && !git_error_last())
+		git_error_set(GIT_ERROR_NET, "user rejected certificate for %s", url->host);
 
-	giterr_state_free(&last_error);
+	git_error_state_free(&last_error);
 	return error;
 }
 
@@ -743,7 +746,7 @@ static int stream_connect(
 {
 	int error;
 
-	GITERR_CHECK_VERSION(stream, GIT_STREAM_VERSION, "git_stream");
+	GIT_ERROR_CHECK_VERSION(stream, GIT_STREAM_VERSION, "git_stream");
 
 	error = git_stream_connect(stream);
 
@@ -783,7 +786,7 @@ static int proxy_headers_complete(http_parser *parser)
 
 	/* Enforce a reasonable cap on the number of replays */
 	if (t->replay_count++ >= GIT_HTTP_REPLAY_MAX) {
-		giterr_set(GITERR_NET, "too many redirects or authentication replays");
+		git_error_set(GIT_ERROR_NET, "too many redirects or authentication replays");
 		return t->parse_error = PARSE_ERROR_GENERIC;
 	}
 
@@ -813,7 +816,7 @@ static int proxy_headers_complete(http_parser *parser)
 			proxy_auth_types);
 
 	if (parser->status_code != 200) {
-		giterr_set(GITERR_NET, "unexpected status code from proxy: %d",
+		git_error_set(GIT_ERROR_NET, "unexpected status code from proxy: %d",
 			parser->status_code);
 		return t->parse_error = PARSE_ERROR_GENERIC;
 	}
@@ -850,8 +853,8 @@ replay:
 	if ((error = gen_connect_req(&request, t)) < 0)
 		goto done;
 
-	if ((error = git_stream_write(proxy_stream,
-	    request.ptr, request.size, 0)) < 0)
+	if ((error = git_stream__write_full(proxy_stream, request.ptr,
+					    request.size, 0)) < 0)
 		goto done;
 
 	git_buf_dispose(&request);
@@ -883,7 +886,7 @@ replay:
 
 		/* Ensure that we didn't get a redirect; unsupported. */
 		if (t->location) {
-			giterr_set(GITERR_NET, "proxy server sent unsupported redirect during CONNECT");
+			git_error_set(GIT_ERROR_NET, "proxy server sent unsupported redirect during CONNECT");
 			error = -1;
 			goto done;
 		}
@@ -898,7 +901,7 @@ replay:
 		}
 
 		if (bytes_parsed != t->parse_buffer.offset) {
-			giterr_set(GITERR_NET,
+			git_error_set(GIT_ERROR_NET,
 				"HTTP parser error: %s",
 				http_errno_description((enum http_errno)t->parser.http_errno));
 			error = -1;
@@ -1031,8 +1034,8 @@ replay:
 		if (gen_request(&request, s, 0) < 0)
 			return -1;
 
-		if (git_stream_write(t->server.stream,
-		    request.ptr, request.size, 0) < 0) {
+		if (git_stream__write_full(t->server.stream, request.ptr,
+					   request.size, 0) < 0) {
 			git_buf_dispose(&request);
 			return -1;
 		}
@@ -1055,7 +1058,8 @@ replay:
 			s->chunk_buffer_len = 0;
 
 			/* Write the final chunk. */
-			if (git_stream_write(t->server.stream, "0\r\n\r\n", 5, 0) < 0)
+			if (git_stream__write_full(t->server.stream,
+						   "0\r\n\r\n", 5, 0) < 0)
 				return -1;
 		}
 
@@ -1125,7 +1129,7 @@ replay:
 			return -1;
 
 		if (bytes_parsed != t->parse_buffer.offset - data_offset) {
-			giterr_set(GITERR_NET,
+			git_error_set(GIT_ERROR_NET,
 				"HTTP parser error: %s",
 				http_errno_description((enum http_errno)t->parser.http_errno));
 			return -1;
@@ -1140,7 +1144,7 @@ static int http_stream_write_chunked(
 	const char *buffer,
 	size_t len)
 {
-	http_stream *s = (http_stream *)stream;
+	http_stream *s = GIT_CONTAINER_OF(stream, http_stream, parent);
 	http_subtransport *t = OWNING_SUBTRANSPORT(s);
 
 	assert(t->connected);
@@ -1154,8 +1158,8 @@ static int http_stream_write_chunked(
 		if (gen_request(&request, s, 0) < 0)
 			return -1;
 
-		if (git_stream_write(t->server.stream,
-		    request.ptr, request.size, 0) < 0) {
+		if (git_stream__write_full(t->server.stream, request.ptr,
+					   request.size, 0) < 0) {
 			git_buf_dispose(&request);
 			return -1;
 		}
@@ -1214,14 +1218,14 @@ static int http_stream_write_single(
 	const char *buffer,
 	size_t len)
 {
-	http_stream *s = (http_stream *)stream;
+	http_stream *s = GIT_CONTAINER_OF(stream, http_stream, parent);
 	http_subtransport *t = OWNING_SUBTRANSPORT(s);
 	git_buf request = GIT_BUF_INIT;
 
 	assert(t->connected);
 
 	if (s->sent_request) {
-		giterr_set(GITERR_NET, "subtransport configured for only one write");
+		git_error_set(GIT_ERROR_NET, "subtransport configured for only one write");
 		return -1;
 	}
 
@@ -1230,11 +1234,10 @@ static int http_stream_write_single(
 	if (gen_request(&request, s, len) < 0)
 		return -1;
 
-	if (git_stream_write(t->server.stream,
-	    request.ptr, request.size, 0) < 0)
+	if (git_stream__write_full(t->server.stream, request.ptr, request.size, 0) < 0)
 		goto on_error;
 
-	if (len && git_stream_write(t->server.stream, buffer, len, 0) < 0)
+	if (len && git_stream__write_full(t->server.stream, buffer, len, 0) < 0)
 		goto on_error;
 
 	git_buf_dispose(&request);
@@ -1249,7 +1252,7 @@ on_error:
 
 static void http_stream_free(git_smart_subtransport_stream *stream)
 {
-	http_stream *s = (http_stream *)stream;
+	http_stream *s = GIT_CONTAINER_OF(stream, http_stream, parent);
 
 	if (s->chunk_buffer)
 		git__free(s->chunk_buffer);
@@ -1269,7 +1272,7 @@ static int http_stream_alloc(http_subtransport *t,
 		return -1;
 
 	s = git__calloc(sizeof(http_stream), 1);
-	GITERR_CHECK_ALLOC(s);
+	GIT_ERROR_CHECK_ALLOC(s);
 
 	s->parent.subtransport = &t->parent;
 	s->parent.read = http_stream_read;
@@ -1362,7 +1365,7 @@ static int http_action(
 	const char *url,
 	git_smart_service_t action)
 {
-	http_subtransport *t = (http_subtransport *)subtransport;
+	http_subtransport *t = GIT_CONTAINER_OF(subtransport, http_subtransport, parent);
 	int ret;
 
 	assert(stream);
@@ -1416,7 +1419,7 @@ static void free_auth_contexts(git_vector *contexts)
 
 static int http_close(git_smart_subtransport *subtransport)
 {
-	http_subtransport *t = (http_subtransport *) subtransport;
+	http_subtransport *t = GIT_CONTAINER_OF(subtransport, http_subtransport, parent);
 
 	clear_parser_state(t);
 
@@ -1456,7 +1459,7 @@ static int http_close(git_smart_subtransport *subtransport)
 
 static void http_free(git_smart_subtransport *subtransport)
 {
-	http_subtransport *t = (http_subtransport *) subtransport;
+	http_subtransport *t = GIT_CONTAINER_OF(subtransport, http_subtransport, parent);
 
 	http_close(subtransport);
 
@@ -1475,7 +1478,7 @@ int git_smart_subtransport_http(git_smart_subtransport **out, git_transport *own
 		return -1;
 
 	t = git__calloc(sizeof(http_subtransport), 1);
-	GITERR_CHECK_ALLOC(t);
+	GIT_ERROR_CHECK_ALLOC(t);
 
 	t->owner = (transport_smart *)owner;
 	t->parent.action = http_action;
